@@ -10,8 +10,7 @@
 #'
 #' @details
 #' `tq_index()` returns the stock symbol, company name, weight, and sector of every stock
-#' in an index. The source is
-#' \href{https://www.ssga.com/us/en/individual/etfs/fund-finder}{www.ssga.com}.
+#' in an index.
 #'
 #' `tq_index_options()` returns a list of stock indexes you can
 #' choose from.
@@ -28,8 +27,6 @@
 #'
 #'
 #' @examples
-#' # Load libraries
-#' library(tidyquant)
 #'
 #' # Get the list of stock index options
 #' tq_index_options()
@@ -113,50 +110,59 @@ tq_exchange <- function(x) {
     }
 
     # Download
+
+    # Example: https://api.nasdaq.com/api/screener/stocks?tableonly=true&exchange=nasdaq&download=true
+
     message("Getting data...\n")
     base_path_1 <- "https://api.nasdaq.com/api/screener/stocks?tableonly=true&exchange="
     base_path_2 <- "&download=true"
     url         <- paste0(base_path_1, x, base_path_2)
-    # res         <- csv_downloader(path = url)
-    res         <- jsonlite::fromJSON(url)
+
+    # Use HTTR2 to make the HTTP request:
+    response <- httr2::request(url) %>%
+        httr2::req_user_agent("Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/113.0.0.0 Safari/537.36") %>%
+        httr2::req_perform()
 
     # Evaluate Response / Clean & Return
-    if (is.null(res$err)) {
-        exchange_raw <- res$data$rows
+    if (response$status_code == 200) {
+
+        # Collect JSON
+        content <- httr2::resp_body_json(response)
 
         # Post-process response
         suppressWarnings({
-          exchange <- exchange_raw %>%
-            dplyr::mutate_if(is.character, stringr::str_trim) %>%
-            dplyr::as_tibble() %>%
-            dplyr::rename(
-              symbol = symbol,
-              company = name,
-              last.sale.price = lastsale,
-              market.cap = marketCap,
-              country = country,
-              ipo.year = ipoyear,
-              sector = sector,
-              industry = industry
-            ) %>%
-            dplyr::mutate(
-              symbol = as.character(symbol),
-              company = as.character(company),
-              last.sale.price = as.numeric(stringr::str_remove(last.sale.price, "\\$")),
-              market.cap = as.numeric(market.cap),
-              country = as.character(country),
-              ipo.year = as.integer(ipo.year),
-              sector = as.character(sector),
-              industry = as.character(industry)
-            ) %>%
-            dplyr::select(symbol:industry) %>%
-            dplyr::select(-c(netchange, pctchange, volume))
+
+            exchange_tbl <- do.call(rbind, lapply(content$data$rows, tibble::as_tibble))
+
+            exchange <- exchange_tbl %>%
+                dplyr::rename(
+                  symbol = symbol,
+                  company = name,
+                  last.sale.price = lastsale,
+                  market.cap = marketCap,
+                  country = country,
+                  ipo.year = ipoyear,
+                  sector = sector,
+                  industry = industry
+                ) %>%
+                dplyr::mutate(
+                  symbol = as.character(symbol),
+                  company = as.character(company),
+                  last.sale.price = as.numeric(stringr::str_remove(last.sale.price, "\\$")),
+                  market.cap = as.numeric(market.cap),
+                  country = as.character(country),
+                  ipo.year = as.integer(ipo.year),
+                  sector = as.character(sector),
+                  industry = as.character(industry)
+                ) %>%
+                dplyr::select(symbol:industry) %>%
+                dplyr::select(-c(netchange, pctchange, volume))
         })
 
         return(exchange)
 
     } else {
-        warn <- paste0("Error at ", x, " during call to tq_exchange.\n\n", res$err)
+        warn <- paste0("Error at ", x, " during call to tq_exchange.\n\n", response)
         warning(warn)
         return(NA) # Return NA on error
     }
@@ -222,7 +228,10 @@ spdr_mapper <- function(x) {
            DOWGLOBAL   = "DGT",
            SP400       = "MDY",
            SP500       = "SPY",
-           SP600       = "SLY",
+           # SLY seems broken.
+           # Using SLYG for S&P 600
+           # https://www.ssga.com/us/en/institutional/etfs/funds/spdr-sp-600-small-cap-growth-etf-slyg
+           SP600       = "SLYG",
            SP1000      = "SMD"
            )
 }
@@ -232,9 +241,10 @@ index_download <- function(x, index_name) {
 
     # Contruct download link
     #     OLD (< 2019-12-15): https://us.spdrs.com/site-content/xls/SPY_All_Holdings.xls
-    #     NEW (> 2019-12-15) https://www.ssga.com/us/en/institutional/etfs/library-content/products/fund-data/etfs/us/holdings-daily-us-en-spy.xlsx
+    #     NEW (> 2019-12-15): https://www.ssga.com/us/en/institutional/etfs/library-content/products/fund-data/etfs/us/holdings-daily-us-en-spy.xlsx
+    #     NEW (> 2024-08-16): https://www.ssga.com/us/en/institutional/library-content/products/fund-data/etfs/us/holdings-daily-us-en-spy.xlsx
     # spdr_link <- paste0("https://us.spdrs.com/site-content/xls/", x, "_All_Holdings.xls")
-    spdr_link <- paste0("https://www.ssga.com/us/en/institutional/etfs/library-content/products/fund-data/etfs/us/holdings-daily-us-en-", tolower(x), ".xlsx")
+    spdr_link <- paste0("https://www.ssga.com/us/en/institutional/library-content/products/fund-data/etfs/us/holdings-daily-us-en-", tolower(x), ".xlsx")
 
     # Results container
     res <- list(df = NULL, err = NULL)
@@ -246,7 +256,7 @@ index_download <- function(x, index_name) {
     tryCatch({
 
         # Download to disk, force as a xlsx
-        httr::GET(spdr_link, httr::write_disk(tf <- tempfile(fileext = ".xlsx")))
+        curl::curl_download(spdr_link, tf <- tempfile(fileext = ".xlsx"))
 
         # Read the xls file
         suppressMessages({
@@ -261,7 +271,7 @@ index_download <- function(x, index_name) {
     }, error = function(e) {
 
         # On error, catch it and return
-        res$err <- paste0("Error at ", index_name, " during download. \n", e)
+        res$err <- paste0("Error at ", index_name, x, " during download. \n", e)
 
         return(res)
 
