@@ -1,4 +1,4 @@
-## ---- echo = FALSE, message = FALSE, warning = FALSE---------------------
+## ----echo = FALSE, message = FALSE, warning = FALSE---------------------------
 knitr::opts_chunk$set(message = FALSE,
                       warning = FALSE,
                       fig.width = 8, 
@@ -7,37 +7,49 @@ knitr::opts_chunk$set(message = FALSE,
                       out.width='95%')
 # devtools::load_all() # Travis CI fails on load_all()
 
-## ------------------------------------------------------------------------
-# Loads tidyquant, lubridate, xts, quantmod, TTR, and PerformanceAnalytics
-library(tidyverse)
+## ----include=FALSE------------------------------------------------------------
+# Loads tidyquant, xts, quantmod, TTR, and PerformanceAnalytics
+library(lubridate)
+library(dplyr)
+library(ggplot2)
 library(tidyquant)  
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # Use FANG data set
-data("FANG") 
-
 # Get AAPL and AMZN Stock Prices
 AAPL <- tq_get("AAPL", get = "stock.prices", from = "2015-09-01", to = "2016-12-31")
 AMZN <- tq_get("AMZN", get = "stock.prices", from = "2000-01-01", to = "2016-12-31")
 
-## ------------------------------------------------------------------------
-end <- as_date("2016-12-31")
+## -----------------------------------------------------------------------------
+end <- lubridate::as_date("2016-12-31")
 
-## ------------------------------------------------------------------------
+end
+
+## -----------------------------------------------------------------------------
+aapl_range_60_tbl <- AAPL %>%
+    tail(60) %>%
+    summarise(
+        max_high = max(high),
+        min_low  = min(low)
+    )
+
+aapl_range_60_tbl
+
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_line() +
     labs(title = "AAPL Line Chart", y = "Closing Price", x = "") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_barchart(aes(open = open, high = high, low = low, close = close)) +
     labs(title = "AAPL Bar Chart", y = "Closing Price", x = "") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_barchart(aes(open = open, high = high, low = low, close = close)) +
@@ -45,10 +57,10 @@ AAPL %>%
          subtitle = "Zoomed in using coord_x_date",
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(6), end),
-                 ylim = c(100, 120)) + 
+                 ylim = c(aapl_range_60_tbl$min_low, aapl_range_60_tbl$max_high)) +
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_barchart(aes(open = open, high = high, low = low, close = close),
@@ -56,18 +68,18 @@ AAPL %>%
     labs(title = "AAPL Bar Chart", 
          subtitle = "Zoomed in, Experimenting with Formatting",
          y = "Closing Price", x = "") + 
-    coord_x_date(xlim = c(end - weeks(6), end),
-                 ylim = c(100, 120)) + 
+    coord_x_date(xlim = c(end - lubridate::weeks(6), end),
+                 c(aapl_range_60_tbl$min_low, aapl_range_60_tbl$max_high)) + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
     labs(title = "AAPL Candlestick Chart", y = "Closing Price", x = "") +
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
@@ -75,10 +87,10 @@ AAPL %>%
          subtitle = "Zoomed in using coord_x_date",
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(6), end),
-                 ylim = c(100, 120)) + 
+                 c(aapl_range_60_tbl$min_low, aapl_range_60_tbl$max_high)) + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close),
@@ -88,37 +100,37 @@ AAPL %>%
          subtitle = "Zoomed in, Experimenting with Formatting",
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(6), end),
-                 ylim = c(100, 120)) + 
+                 c(aapl_range_60_tbl$min_low, aapl_range_60_tbl$max_high)) + 
     theme_tq()
 
-## ---- fig.height=5-------------------------------------------------------
+## ----fig.height=5-------------------------------------------------------------
 start <- end - weeks(6)
 FANG %>%
-    filter(date >= start - days(2 * 15)) %>%
+    dplyr::filter(date >= start - days(2 * 15)) %>%
     ggplot(aes(x = date, y = close, group = symbol)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
     labs(title = "FANG Candlestick Chart", 
-         subtitle = "Experimenting with Mulitple Stocks",
+         subtitle = "Experimenting with Multiple Stocks",
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(start, end)) +
     facet_wrap(~ symbol, ncol = 2, scale = "free_y") + 
     theme_tq()
 
-## ---- fig.height=5-------------------------------------------------------
+## ----fig.height=5-------------------------------------------------------------
 start <- end - weeks(6)
 FANG %>%
-    filter(date >= start - days(2 * 15)) %>%
+    dplyr::filter(date >= start - days(2 * 15)) %>%
     ggplot(aes(x = date, y = close, group = symbol)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
     geom_ma(ma_fun = SMA, n = 15, color = "darkblue", size = 1) +
     labs(title = "FANG Candlestick Chart", 
-         subtitle = "Experimenting with Mulitple Stocks",
+         subtitle = "Experimenting with Multiple Stocks",
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(start, end)) +
     facet_wrap(~ symbol, ncol = 2, scale = "free_y") +
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
@@ -128,10 +140,10 @@ AAPL %>%
          subtitle = "50 and 200-Day SMA", 
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(24), end),
-                 ylim = c(100, 120)) + 
+                 c(aapl_range_60_tbl$min_low * 0.9, aapl_range_60_tbl$max_high)) + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close)) +
     geom_barchart(aes(open = open, high = high, low = low, close = close)) +
@@ -141,13 +153,13 @@ AAPL %>%
          subtitle = "50 and 200-Day EMA", 
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(24), end),
-                 ylim = c(100, 120)) +
+                 c(aapl_range_60_tbl$min_low * 0.9, aapl_range_60_tbl$max_high)) +
     theme_tq()
 
-## ---- fig.height=5-------------------------------------------------------
+## ----fig.height=5-------------------------------------------------------------
 start <- end - weeks(6)
 FANG %>%
-    filter(date >= start - days(2 * 50)) %>%
+    dplyr::filter(date >= start - days(2 * 50)) %>%
     ggplot(aes(x = date, y = close, volume = volume, group = symbol)) +
     geom_candlestick(aes(open = open, high = high, low = low, close = close)) +
     geom_ma(ma_fun = VWMA, n = 15, wilder = TRUE, linetype = 5) +
@@ -159,7 +171,7 @@ FANG %>%
     facet_wrap(~ symbol, ncol = 2, scales = "free_y") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close, open = open,
                high = high, low = low, close = close)) +
@@ -169,10 +181,11 @@ AAPL %>%
          subtitle = "BBands with SMA Applied", 
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(24), end),
-                 ylim = c(100, 120)) + 
+                 ylim = c(aapl_range_60_tbl$min_low * 0.85, 
+                          aapl_range_60_tbl$max_high) * 1.05) + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AAPL %>%
     ggplot(aes(x = date, y = close, open = open,
                high = high, low = low, close = close)) +
@@ -186,13 +199,14 @@ AAPL %>%
          subtitle = "BBands with SMA Applied, Experimenting with Formatting", 
          y = "Closing Price", x = "") + 
     coord_x_date(xlim = c(end - weeks(24), end),
-                 ylim = c(100, 120)) + 
+                 ylim = c(aapl_range_60_tbl$min_low * 0.85, 
+                          aapl_range_60_tbl$max_high) * 1.05) + 
     theme_tq()
 
-## ---- fig.height=5-------------------------------------------------------
+## ----fig.height=5-------------------------------------------------------------
 start <- end - weeks(24)
 FANG %>%
-    filter(date >= start - days(2 * 20)) %>%
+    dplyr::filter(date >= start - days(2 * 20)) %>%
     ggplot(aes(x = date, y = close, 
                open = open, high = high, low = low, close = close, 
                group = symbol)) +
@@ -205,7 +219,7 @@ FANG %>%
     facet_wrap(~ symbol, ncol = 2, scales = "free_y") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AMZN %>%
     ggplot(aes(x = date, y = adjusted)) +
     geom_line(color = palette_light()[[1]]) + 
@@ -215,7 +229,7 @@ AMZN %>%
          y = "Closing Price", x = "") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AMZN %>%
     ggplot(aes(x = date, y = adjusted)) +
     geom_line(color = palette_light()[[1]]) + 
@@ -225,7 +239,7 @@ AMZN %>%
          y = "Closing Price", x = "") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AMZN %>%
     ggplot(aes(x = date, y = adjusted)) +
     geom_line(color = palette_light()[[1]]) + 
@@ -236,7 +250,7 @@ AMZN %>%
          y = "Adjusted Closing Price", x = "") + 
     theme_tq()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 AMZN %>%
     ggplot(aes(x = date, y = volume)) +
     geom_segment(aes(xend = date, yend = 0, color = volume)) + 
@@ -247,10 +261,10 @@ AMZN %>%
     theme_tq() +
     theme(legend.position = "none") 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 start <- end - weeks(24)
 AMZN %>%
-    filter(date >= start - days(50)) %>%
+    dplyr::filter(date >= start - days(50)) %>%
     ggplot(aes(x = date, y = volume)) +
     geom_segment(aes(xend = date, yend = 0, color = volume)) +
     geom_smooth(method = "loess", se = FALSE) +
@@ -262,12 +276,12 @@ AMZN %>%
     theme_tq() + 
     theme(legend.position = "none") 
 
-## ---- fig.height = 6-----------------------------------------------------
+## ----fig.height = 6-----------------------------------------------------------
 n_mavg <- 50 # Number of periods (days) for moving average
 FANG %>%
-    filter(date >= start - days(2 * n_mavg)) %>%
+    dplyr::filter(date >= start - days(2 * n_mavg)) %>%
     ggplot(aes(x = date, y = close, color = symbol)) +
-    geom_line(size = 1) +
+    geom_line(linewidth = 1) +
     geom_ma(n = 15, color = "darkblue", size = 1) + 
     geom_ma(n = n_mavg, color = "red", size = 1) +
     labs(title = "Dark Theme",
@@ -276,5 +290,5 @@ FANG %>%
     facet_wrap(~ symbol, scales = "free_y") +
     theme_tq_dark() +
     scale_color_tq(theme = "dark") +
-    scale_y_continuous(labels = scales::dollar)
+    scale_y_continuous(labels = scales::label_dollar())
 
